| base64dec | R Documentation |
Decodes a character string, raw vector or other object from base64 encoding.
base64dec(x, convert = TRUE, url = FALSE)
x |
an object. |
convert |
logical |
url |
logical |
The value of convert should be set to TRUE, FALSE or NA to be the
reverse of the 3 encoding operations (for strings, raw vectors and arbitrary
objects), in order to return the original object.
Set url = TRUE to decode the URL- and filename-safe variant (RFC 4648
section 5), which expects the - and _ alphabet without padding; inputs
containing +, / or = are then rejected. The value of url must match
the variant used to encode.
A character string, raw vector, or other object depending on the
value of convert.
This implementation is based that by 'The Mbed TLS Contributors' under the 'Mbed TLS' Trusted Firmware Project at https://www.trustedfirmware.org/projects/mbed-tls.
base64enc()
base64dec(base64enc("secret base"))
base64dec(base64enc(as.raw(c(1L, 2L, 4L))), convert = FALSE)
base64dec(base64enc(data.frame()), convert = NA)
base64dec(base64enc("secret base", url = TRUE), url = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.